@@ -1,24 +1,21 @@
 package Workflow::Action;
 
-# $Id: Action.pm 454 2009-01-12 10:04:02Z jonasbn $
+# $Id: Action.pm,v 1.5 2004/05/14 05:13:52 cwinters Exp $
 
 # Note: we may implement a separate event mechanism so that actions
 # can trigger other code (use 'Class::Observable'? read observations
 # from database?)
 
-use warnings;
 use strict;
 use base qw( Workflow::Base );
-use Log::Log4perl qw( get_logger );
+use Log::Log4perl     qw( get_logger );
 use Workflow::Action::InputField;
-use Workflow::Validator::HasRequiredField;
 use Workflow::Factory qw( FACTORY );
-use Carp qw(croak);
 
-$Workflow::Action::VERSION = '1.09';
+$Workflow::Action::VERSION  = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( name class description );
-__PACKAGE__->mk_accessors(@FIELDS);
+__PACKAGE__->mk_accessors( @FIELDS );
 
 ####################
 # INPUT FIELDS
@@ -29,17 +26,17 @@ sub add_fields {
 }
 
 sub required_fields {
-    my ($self) = @_;
-    return grep { $_->requirement() eq 'required' } @{ $self->{_fields} };
+    my ( $self ) = @_;
+    return grep { $_->{type} eq 'required' } @{ $self->{_fields} };
 }
 
 sub optional_fields {
-    my ($self) = @_;
-    return grep { $_->requirement() eq 'optional' } @{ $self->{_fields} };
+    my ( $self ) = @_;
+    return grep { $_->{type} eq 'optional' } @{ $self->{_fields} };
 }
 
 sub fields {
-    my ($self) = @_;
+    my ( $self ) = @_;
     return @{ $self->{_fields} };
 }
 
@@ -49,20 +46,17 @@ sub fields {
 sub add_validators {
     my ( $self, @validator_info ) = @_;
     my @validators = ();
-    foreach my $conf (@validator_info) {
+    foreach my $conf ( @validator_info ) {
         my $validator = FACTORY->get_validator( $conf->{name} );
-        my @args      = $self->normalize_array( $conf->{arg} );
-        push @validators,
-            {
-            validator => $validator,
-            args      => \@args
-            };
+        my @args = $self->normalize_array( $conf->{arg} );
+        push @validators, { validator => $validator,
+                            args      => \@args };
     }
     push @{ $self->{_validators} }, @validators;
 }
 
 sub get_validators {
-    my ($self) = @_;
+    my ( $self ) = @_;
     return @{ $self->{_validators} };
 }
 
@@ -72,26 +66,27 @@ sub validate {
     return unless ( scalar @validators );
 
     my $context = $wf->context;
-    foreach my $validator_info (@validators) {
-        my $validator    = $validator_info->{validator};
-        my $args         = $validator_info->{args};
-        my @runtime_args = ($wf);
-        foreach my $arg ( @{$args} ) {
+    foreach my $validator_info ( @validators ) {
+        my $validator = $validator_info->{validator};
+        my $args      = $validator_info->{args};
+        my @runtime_args = ( $wf );
+        foreach my $arg ( @{ $args } ) {
             if ( $arg =~ /^\$(.*)$/ ) {
-                push @runtime_args, $context->param($1);
-            } else {
+                push @runtime_args, $context->param( $1 );
+            }
+            else {
                 push @runtime_args, $arg;
             }
         }
-        $validator->validate(@runtime_args);
+        $validator->validate( @runtime_args );
     }
 }
 
 # Subclasses override...
 
-sub execute {
+sub execute  {
     my ( $self, $wf ) = @_;
-    croak "Class ", ref($self), " must implement 'execute()'\n";
+    die "Class ", ref( $self ), " must implement 'execute()'\n";
 }
 
 ########################################
@@ -101,41 +96,21 @@ sub init {
     my ( $self, $wf, $params ) = @_;
 
     # So we don't destroy the original...
-    my %copy_params = %{$params};
+    my %copy_params = %{ $params };
 
     $self->class( $copy_params{class} );
     $self->name( $copy_params{name} );
     $self->description( $copy_params{description} );
 
-    ## init normal fields
     my @fields = $self->normalize_array( $copy_params{field} );
-    foreach my $field_info (@fields) {
-        $self->add_fields( Workflow::Action::InputField->new($field_info) );
+    foreach my $field_info ( @fields ) {
+        $self->add_fields( Workflow::Action::InputField->new( $field_info ) );
     }
 
-    ## establish validator for fields with is_required="yes"
-    @fields = $self->required_fields();
-    my $validator = Workflow::Validator::HasRequiredField->new(
-        {   name  => 'HasRequiredField for is_required fields',
-            class => 'Workflow::Validator::HasRequiredField'
-        }
-    );
-    my @args = ();
-    foreach my $field (@fields) {
-        next if ( not $field );    ## empty @fields array
-        push @args, $field->name();
-    }
-    push @{ $self->{_validators} },
-        {
-        validator => $validator,
-        args      => \@args
-        };
-
-    ## init normal validators
     my @validator_info = $self->normalize_array( $copy_params{validator} );
-    $self->add_validators(@validator_info);
+    $self->add_validators( @validator_info );
 
-    delete @copy_params{qw( class name description field validator )};
+    delete @copy_params{ qw( class name description field validator ) };
 
     # everything else is just a passthru param
 
@@ -144,6 +119,7 @@ sub init {
     }
 }
 
+
 1;
 
 __END__
@@ -152,10 +128,6 @@ __END__
 
 Workflow::Action - Base class for Workflow actions
 
-=head1 VERSION
-
-This documentation describes version 1.09 of this package
-
 =head1 SYNOPSIS
 
  # Configure the Action...
@@ -172,12 +144,12 @@ This documentation describes version 1.09 of this package
  </action>
 
  # Define the action
-
+ 
  package MyApp::Action::CreateUser;
-
+ 
  use base qw( Workflow::Action );
  use Workflow::Exception qw( workflow_error );
-
+ 
  sub execute {
      my ( $self, $wf ) = @_;
      my $context = $wf->context;
@@ -194,16 +166,13 @@ This documentation describes version 1.09 of this package
 
      if ( $@ ) {
          workflow_error
-             "Cannot create new user with name '", $context->param( 'username' ), "': $EVAL_ERROR";
+             "Cannot create new user with name '", $context->param( 'username' ), "': $@";
      }
 
      # Set the created user in the context for the application and/or
      # other actions (observers) to use
 
      $context->param( user => $user );
-
-     # return the username since it might be used elsewhere...
-     return $user->username;
  }
 
 =head1 DESCRIPTION
@@ -211,64 +180,35 @@ This documentation describes version 1.09 of this package
 This is the base class for all Workflow Actions. You do not have to
 use it as such but it is strongly recommended.
 
-=head1 CONFIGURATION
-
-You configure your actions and map them to a specific module in your actions
-configuration file using the syntax
-above and that shown in L<Workflow>. In some cases, you'll have actions
-that apply to all workflows. In more elaborate configurations, you may have
-one workflow server loading multiple workflows and multiple actions for each.
-In these
-cases, you'll have multiple workflow types and you may want actions
-with the same names to have different behaviors for each type.
-
-For example, you may have a workflow type Ticket and another type Order_Parts.
-They both may have a Submit action, but you'll want the Submit to be different
-for each.
-
-You can specify a type in your actions configuration to associate that action
-with that workflow type. If you don't provide a type, the action is available
-to all types. For example:
-
-  <actions>
-    <type>Ticket</type>
-    <description>Actions for the Ticket workflow only.</description>
-    <action name="TIX_NEW"
-           class="TestApp::Action::TicketCreate">
-  ...Addtional configuration...
-
-The type must match an existing workflow type or the action will never
-be called.
-
 =head1 OBJECT METHODS
 
 =head2 Public Methods
 
-=head3 add_field( @fields )
+B<add_field( @fields )>
 
 Add one or more L<Workflow::Action::InputField>s to the action.
 
-=head3 required_fields()
+B<required_fields()>
 
 Return a list of L<Workflow::Action::InputField> objects that are required.
 
-=head3 optional_fields()
+B<optional_fields()>
 
 Return a list of L<Workflow::Action::InputField> objects that are optional.
 
-=head3 fields()
+B<fields()>
 
 Return a list of all L<Workflow::Action::InputField> objects
 associated with this action.
 
-=head3 add_validators( @validator_config )
+B<add_validators( @validator_config )>
 
 Given the 'validator' configuration declarations in the action
 configuration, ask the L<Workflow::Factory> for the
 L<Workflow::Validator> object associated with each name and store that
 along with the arguments to be used, runtime and otherwise.
 
-=head3 get_validators()
+B<get_validators()>
 
 Get a list of all the validator hashrefs, each with two keys:
 'validator' and 'args'. The 'validator' key contains the appropriate
@@ -276,30 +216,18 @@ L<Workflow::Validator> object, while 'args' contains an arrayref of
 arguments to pass to the validator, some of which may need to be
 evaluated at runtime.
 
-=head3 validate( $workflow )
+B<validate( $workflow )>
 
 Run through all validators for this action. If any fail they will
 throw a L<Workflow::Exception>, the validation subclass.
 
-=head3 execute( $workflow )
+B<execute( $workflow )>
 
-Subclasses B<must> implement -- this will perform the actual
-work. It's not required that you return anything, but if the action
-may be used in a L<Workflow::State> object that has multiple resulting
-states you should return a simple scalar for a return value.
-
-=head3 add_fields
-
-Method to add fields to the workflow. The method takes an array of
-fields.
+Subclasses B<must> implement.
 
 =head2 Private Methods
 
-=head3 init( $workflow, \%params )
-
-init is called in conjuction with the overall workflow initialization.
-
-It sets up the necessary validators based on the on configured actions, input fields and required fields.
+B<init( $workflow, \%params )>
 
 =head1 SEE ALSO
 
