@@ -1,6 +1,6 @@
 package Workflow::Exception;
 
-# $Id: Exception.pm 301 2007-07-03 14:54:01Z jonasbn $
+# $Id: Exception.pm,v 1.6 2004/05/14 05:13:52 cwinters Exp $
 
 use strict;
 
@@ -35,7 +35,7 @@ my %TYPE_CLASSES = (
     workflow_error      => 'Workflow::Exception',
 );
 
-$Workflow::Exception::VERSION   = '1.08';
+$Workflow::Exception::VERSION   = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 @Workflow::Exception::ISA       = qw( Exporter Exception::Class::Base );
 @Workflow::Exception::EXPORT_OK = keys %TYPE_CLASSES;
 
@@ -46,9 +46,7 @@ sub _mythrow {
     my ( $msg, %params ) = _massage( @_ );
     my $log = get_logger();
     my ( $pkg, $line ) = (caller)[0,2];
-    my ( $prev_pkg, $prev_line ) = (caller(1))[0,2];
-    $log->error( "$type exception thrown from [$pkg: $line; before: ",
-                 "$prev_pkg: $prev_line]: $msg" );
+    $log->error( "$type exception thrown from [$pkg: $line]: $msg" );
     goto &Exception::Class::Base::throw( $TYPE_CLASSES{ $type },
                                          message => $msg, %params );
 }
@@ -141,7 +139,7 @@ exception easier and more readable.
 
 =head1 METHODS
 
-=head3 throw( @msg, [ \%params ])
+B<throw( @msg, [ \%params ])>
 
 This overrides B<throw()> from L<Exception::Class|Exception::Class> to
 add a little syntactic sugar. Instead of:
@@ -164,37 +162,7 @@ makes for very readable code:
                 "frightfully wrong: $@",
                 { foo => 'bar' };
 
-=head3 condition_error
-
-This method transforms the error to a condition error.
-
-This exception is thrown via </mythrow> when a condition of a workflow is invalid.
-
-=head3 configuration_error
-
-This method transforms the error to a configuration error.
-
-This exception is thrown via </mythrow> when configuration of a workflow is unsuccessful.
-
-=head3 persist_error
-
-This method transforms the error to a persistance error.
-
-This exception is thrown via </mythrow> when the save of a workflow is unsuccessful.
-
-=head3 validation_error
-
-This method transforms the error to a validation error.
-
-This exception is thrown via </mythrow> when input data or similar of a workflow is unsuccessful.
-
-=head3 workflow_error
-
-This method transforms the error to a workflow error.
-
-This exception is thrown via </mythrow> when input data or similar of a workflow is unsuccessful.
-
-=head1 SHORTCUTS
+=head1 DECLARED EXCEPTION CLASSES
 
 B<Workflow::Exception> - import using C<workflow_error>
 
